<?php
/**
 * Portfolio Ajax shortcode for Visual Composer
 *
 * @package Deeper Addons
 */

if ( ! class_exists( 'Deeper_Portfolio_Ajax_Shortcode' ) ) {
	
	class Deeper_Portfolio_Ajax_Shortcode {

		// Constructor
		public function __construct() {			

			// Add shortcode
			add_shortcode( 'deeper_portfolioajax', array( 'Deeper_Portfolio_Ajax_Shortcode', 'output' ) );

			// Ajax loadmore script
			add_action( 'wp_enqueue_scripts', array( 'Deeper_Portfolio_Ajax_Shortcode', 'ajax_load_more_scripts' ) );

			// Ajax request hooks for all user
			add_action( 'wp_ajax_loadmore', array( 'Deeper_Portfolio_Ajax_Shortcode', 'ajax_build_data' ) );
			add_action( 'wp_ajax_nopriv_loadmore', array( 'Deeper_Portfolio_Ajax_Shortcode', 'ajax_build_data' ) );

			// Map to VC
			if ( function_exists( 'vc_lean_map' ) ) {
				vc_lean_map( 'deeper_portfolioajax', array( 'Deeper_Portfolio_Ajax_Shortcode', 'map' ) );
			}
		}
 
		// Displays shortcodes 
		public static function output( $atts, $content ) {		
			$data = $cls = '';
			extract( shortcode_atts( array(
				'style' 		=> 'style-1',
				'btn_text'		=> '',
				'btn_url'		=> '',
				'items'			=> '6',
				'cat_slug'		=> '',
				'exclude_cat_slug' => '',
				'image_crop' 	=> 'full',
				'layout'		=> 'grid',
			    'column'        => '3',
			    'column2'       => '3',
			    'column3'       => '2',
			    'column4'       => '1',
			    'gaph'       => '',
			    'gaph2'       => 'inherit',
			    'gaph3'       => 'inherit',
			    'gaph4'       => 'inherit',
			    'gapv'       => '',
			    'gapv2'       => 'inherit',
			    'gapv3'       => 'inherit',
			    'gapv4'       => 'inherit',

			    'loadmore' => '',
			    'loadmore_text' => 'Load More',
			    'show_filter' => '',
			    'filter_button_all' => '',

			    //Animation
			    'animation' => '',
				'animation_effect' => 'fadeInUp',
				'animation_duration' => '0.75s',
				'animation_delay' => '0.3s',
				
				'class' => '',
			), $atts ) );

			$args = array(
			    'post_type' => 'project',
			    'posts_per_page' => intval( $items )
			);

			if ( ! empty( $cat_slug ) ) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'project_category',
						'field'    => 'slug',
						'terms'    => $cat_slug
					),
				);
			}

			if ( ! empty( $exclude_cat_slug ) ) {
				$args['tax_query'] = array(
				    array(
				        'taxonomy' => 'project_category',
				        'field' => 'slug',
				        'terms' => $exclude_cat_slug,
				        'operator' => 'NOT IN'
				    ),
				);
			}

			$args['image_crop'] = $image_crop;
			$cls = $style;
			if ( $class ) $cls .= ' ' . $class;

			$query = new WP_Query( $args );
			if ( ! $query->have_posts() ) { esc_html_e( 'Project item not found!', 'deeper' ); return; }

			//Animation
			if ( $animation ) {
			    $cls .= ' wow '. $animation_effect;
			    $data .= ' data-wow-duration="'. $animation_duration .'" data-wow-delay="'. $animation_delay .'"';
			}

			$config = array();
			$filter = 'filter-' . rand();
			$config['filters'] = '.' . $filter;
			$config['defaultFilter'] = '*';
			$config['animationType'] = 'quicksand';
			$config['showNavigation'] = true;
			$config['showPagination'] = true;
			$config['rewindNav'] = false;
			$config['auto'] = false;
			$config['caption'] = '';
			$config['displayType'] = 'sequentially';
			$config['displayTypeSpeed'] = '100';
			$config['mediaQueries']['0']['width'] = 1500;
			$config['mediaQueries']['1']['width'] = 923;
			$config['mediaQueries']['2']['width'] = 878;
			$config['mediaQueries']['3']['width'] = 675;
			$config['mediaQueries']['4']['width'] = 502;

			if ( $layout == 'grid' ) {
				$config['layoutMode'] = 'grid';
				$config['gridAdjustment'] = 'responsive';
			} else {
				$config['layoutMode'] = 'mosaic';
				$config['gridAdjustment'] = 'default';
				$config['sortToPreventGaps'] = false;
			}
			$config['mediaQueries']['0']['cols'] = intval( $column );
			$config['mediaQueries']['1']['cols'] = intval( $column );
			$config['mediaQueries']['2']['cols'] = intval( $column2 );
			$config['mediaQueries']['3']['cols'] = intval( $column3 );
			$config['mediaQueries']['4']['cols'] = intval( $column4 );
			$config['gapHorizontal'] = intval( $gaph );
			$config['gapVertical'] = intval( $gapv );

			if ( $gaph2 == 'inherit' ) $gaph2 = intval( $gaph );
			if ( $gaph3 == 'inherit' ) $gaph3 = intval( $gaph2 );
			if ( $gaph4 == 'inherit' ) $gaph4 = intval( $gaph3 );
			if ( $gapv2 == 'inherit' ) $gapv2 = intval( $gapv );
			if ( $gapv3 == 'inherit' ) $gapv3 = intval( $gapv2 );
			if ( $gapv4 == 'inherit' ) $gapv4 = intval( $gapv3 );

			$config['mediaQueries']['2']['options']['gapHorizontal'] = intval( $gaph2 );
			$config['mediaQueries']['3']['options']['gapHorizontal'] = intval( $gaph3 );
			$config['mediaQueries']['4']['options']['gapHorizontal'] = intval( $gaph4 );
			$config['mediaQueries']['2']['options']['gapVertical'] = intval( $gapv2 );
			$config['mediaQueries']['3']['options']['gapVertical'] = intval( $gapv3 );
			$config['mediaQueries']['4']['options']['gapVertical'] = intval( $gapv4 );

			if ( $config )
				$data = 'data-config=\'' . json_encode( $config ) . '\'';

			ob_start(); ?>
				<div class="deeper-cubeportfolio <?php echo esc_html( $cls ); ?>" <?php echo $data; ?> data-inviewport="yes">

					<?php if ( $query->have_posts() ) : 
						// Filter
						if ( $show_filter ) { ?>
					        <div class="cube-filter <?php echo esc_attr( $filter ); ?>">					        	
					        	<div class="inner">
					        		<?php if ( ! empty( $filter_button_all ) )
				        				echo '<div data-filter="*" class="cbp-filter-item button-all"><span>'. esc_html( $filter_button_all ) .'</span><div class="cbp-filter-counter"></div></div>';

									if ( $cat_slug ) {

										$term = strtolower( str_replace( ' ', '-', $cat_slug ) );
										$term = get_term_by( 'slug', $cat_slug, 'project_category' ); 
										if ( $term ) $terms = get_term_children( $term->term_id, 'project_category' );

										foreach( $terms as $term ) {
											$t = get_term_by( 'id', $term, 'project_category' );
											echo '<div data-filter=".'. esc_attr( $t->slug ) .'" class="cbp-filter-item" title="'. esc_attr( $t->name ) .'"><span>'. $t->name . '</span><div class="cbp-filter-counter"></div></div>';
										}
									} else {

										$terms = get_terms( 'project_category' );
									    foreach ( $terms as $term ) {
									        echo '<div data-filter=".'. esc_attr( $term->slug ) .'" class="cbp-filter-item" title="'. esc_attr( $term->name ) .'"><span>'. $term->name .'</span><div class="cbp-filter-counter"></div></div>';
									    }
									} ?>
								</div><!-- /.inner -->
					        </div><!-- /#project-filter -->
					    <?php } 
					    
						// Galleries ?>
						<div id="portfolio-galleries" class="cbp cube-galleries">
						    <?php while ( $query->have_posts() ) : $query->the_post(); 
						    	wp_enqueue_script( 'cubeportfolio' ); 
						    	wp_enqueue_script( 'magnificpopup' ); 
						    	
	                    		global $post;
								$term_list = '';
							    $terms = get_the_terms( $post->ID, 'project_category' );

							    if ( $terms ) {
							        foreach ( $terms as $term ) {
							            $term_list .= $term->slug .' ';
							        }
							    } ?>
								
								<div class="cbp-item <?php echo esc_attr( $term_list ); ?>">
									<div class="project-item">
										<?php switch ( $style ) {
											case 'style-2': ?>
												<div class="project-image">
													<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	
												</div>

												<div class="text-wrap">
													<?php
													if ( octavian_metabox( 'title' ) ) 
														echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

													if ( $terms[0]->name ) 
														echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';
													?> 
												</div>

												<?php break;

											case 'style-3': ?>
												<div class="project-image">
													<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	
												</div>

												<div class="text-wrap">
													<?php
													if ( octavian_metabox( 'title' ) ) 
														echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

													if ( $terms[0]->name ) 
														echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';
													?> 
												</div>

												<?php break;
											
											case 'style-4': ?>
												<div class="project-image">
													<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	

													<div class="text-wrap">
														<?php
														if ( octavian_metabox( 'title' ) ) 
															echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

														if ( $terms[0]->name ) 
															echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';

														if ( $btn_url )
															echo '<a class="project-btn" href="' . esc_url( vc_build_link( $btn_url )['url'] ) . '">' . esc_attr( $btn_text ) . '</a>';
														?> 
													</div>
												</div>	

												<?php break;

											case 'style-5': ?>
												<div class="project-image">
													<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	

													<div class="text-wrap">
														<?php
														if ( octavian_metabox( 'title' ) ) 
															echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

														if ( $terms[0]->name ) 
															echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';

														if ( $btn_url )
															echo '<a class="project-btn" href="' . esc_url( vc_build_link( $btn_url )['url'] ) . '">' . esc_attr( $btn_text ) . '</a>';
														?> 
													</div>
												</div>	

												<?php break;

											default: ?>
												<div class="project-image">
													<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	

													<?php
													if ( octavian_metabox( 'title' ) || octavian_metabox( 'project_desc' ) ) { ?>
														<div class="text-wrap">
															<?php
															if ( octavian_metabox( 'title' ) ) 
																echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

															if ( octavian_metabox( 'project_desc' ) ) 
																echo '<div class="project-desc">' . octavian_metabox( 'project_desc' ) .'</div>';
															?> 
														</div>
													<?php } ?>
												</div>

												<?php break;
										} ?>
										
									</div><!-- /.project-item -->
								</div><!-- /.cbp-item -->

							<?php endwhile; ?>
						</div><!-- /galleries -->
					<?php endif; wp_reset_postdata(); ?>
				
				</div><!-- /.deeper-portfolio -->

				<?php
				if ( $loadmore )
			        if (  $query->max_num_pages > 1 )
			            printf(
			        		'<div class="project-loadmore" style="clear:both;" data-query="%1$s">
			        			<span class="loadmore-btn">
			        				%2$s
			        			</span>
			        		</div>',
			        		esc_attr( json_encode( $args ) ),
			        		$loadmore_text
			        	);

			$return = ob_get_clean();
			return $return;
		}

		// Build data from $_POST ajax
		public static function ajax_build_data( ) {
			// Check nonce from POST action
			check_ajax_referer( 'ajax_more_posts', 'nonce' );

			// Prepare args for query
			$args = json_decode( stripslashes( $_POST['query'] ), true );
			$args['post_status'] = 'publish';
			$args['paged'] = $_POST['page'] + 1;

			// Query posts
			query_posts( $args );
		 
			if( have_posts() ) :
				while( have_posts() ): the_post(); ?>				
					<div class="cbp-item <?php echo esc_attr( $term_list ); ?>">
						<div class="project-item">
							<?php switch ( $style ) {
								case 'style-2': ?>
									<div class="project-image">
										<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	
									</div>

									<div class="text-wrap">
										<?php
										if ( octavian_metabox( 'title' ) ) 
											echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

										if ( $terms[0]->name ) 
											echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';
										?> 
									</div>

									<?php break;

								case 'style-3': ?>
									<div class="project-image">
										<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	
									</div>

									<div class="text-wrap">
										<?php
										if ( octavian_metabox( 'title' ) ) 
											echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

										if ( $terms[0]->name ) 
											echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';
										?> 
									</div>

									<?php break;
								
								case 'style-4': ?>
									<div class="project-image">
										<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	

										<div class="text-wrap">
											<?php
											if ( octavian_metabox( 'title' ) ) 
												echo '<h2 class="project-title"><a href="' . esc_url( get_the_permalink() ) . '">' . octavian_metabox( 'title' ) .'</a></h2>'; 

											if ( $terms[0]->name ) 
												echo '<div class="project-cat"><a href="' . esc_url( get_term_link ( $terms[0]->term_id, 'project_category' ) ) . '">' . $terms[0]->name . '</a></div>';

											if ( $btn_url )
												echo '<a class="project-btn" href="' . esc_url( vc_build_link( $btn_url )['url'] ) . '">' . esc_attr( $btn_text ) . '</a>';
											?> 
										</div>
									</div>	

									<?php break;

								default: ?>
									<div class="project-image">
										<?php echo get_the_post_thumbnail( get_the_ID(), $image_crop ); ?>	

										<a class="arrow" href="<?php the_permalink(); ?>"></a>

										<?php
										if ( octavian_metabox( 'title' ) || octavian_metabox( 'project_desc' ) ) { ?>
											<div class="text-wrap">
												<?php
												if ( octavian_metabox( 'title' ) ) 
													echo '<h2 class="project-title">' . octavian_metabox( 'title' ) .'</h2>'; 

												if ( octavian_metabox( 'project_desc' ) ) 
													echo '<div class="project-desc">' . octavian_metabox( 'project_desc' ) .'</div>';
												?> 
											</div>
										<?php } ?>
									</div>

									<?php break;
							} ?>
							
						</div><!-- /.project-item -->
					</div><!-- /.cbp-item -->

		 		<?php
				endwhile;
			endif;

			die;
		}

		// Pass localize params to ajax script
		public static function ajax_load_more_scripts() {
			wp_register_script( 'deeper_loadmore', DEEPER_URL .'/assets/js/deeper-loadmore.js', array( 'jquery' ) );
			wp_localize_script( 'deeper_loadmore', 'ajax_params', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce( 'ajax_more_posts' )
			) );

			wp_enqueue_script( 'deeper_loadmore' );
		}

		// Map shortcode to VC
		public static function map() {		

		    return array( 
		    	'name' => __( 'Portfolio Ajax', 'deeper' ),
				'description' => __( 'Displays Project.', 'deeper' ),
				'base' => 'deeper_portfolioajax',
				'weight'	=>	180,
				'icon' => plugins_url( '../../assets/icon/portfolio.png', __FILE__ ),
				'category' => __( 'Deeper Addons', 'deeper' ),
				'params' => array(
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Style', 'deeper' ),
						'param_name' => 'style',
						'value'      => array(
							'Style 1' => 'style-1',
							'Style 2' => 'style-2',
							'Style 3' => 'style-3',
							'Style 4' => 'style-4',
						),
						'std'		=> 'style-1',
					),
					array(
						'type' => 'textfield',
						'heading' => __( 'Button Text', 'deeper' ),
						'param_name' => 'btn_text',
						'value' => '',
						'dependency' => array( 'element' => 'style', 'value' => array( 'style-4', 'style-5' ) )
		            ),
		            array(
						'type' => 'vc_link',
						'heading' => __( 'Button URL', 'deeper' ),
						'param_name' => 'btn_url',
						'value' => '',
						'dependency' => array( 'element' => 'style', 'value' => array( 'style-4', 'style-5' ) )
		            ),
					array(
						'type' => 'textfield',
						'heading' => __( 'Posts Per Page', 'deeper' ),
						'param_name' => 'items',
						'value' => '6',
		            ),
		            array(
						'type'       => 'dropdown',
						'heading'    => __( 'Image Cropping', 'deeper' ),
						'param_name' => 'image_crop',
						'value'      => array(
							'Full' => 'full',
							'570 x 420' => 'deeper-std1',
							'570 x 340' => 'deeper-std2',
							'370 x 470' => 'deeper-std3',
							'370 x 430' => 'deeper-std4',
							'370 x 370' => 'deeper-std5',
							'370 x 270' => 'deeper-std6',
						),
						'std'		=> 'full',
					),
			        array(
						'type' => 'textfield',
						'heading' => __( 'Category Slug (Optional)', 'deeper' ),
						'param_name' => 'cat_slug',
						'value' => '',
						'description'	=> __( 'Displaying posts that have this category. Using category-slug.', 'deeper' ),
			        ),	 
			        array(
						'type' => 'textfield',
						'heading' => esc_html__( 'Exclude Category Slug (Optional)', 'deeper' ),
						'param_name' => 'exclude_cat_slug',
						'value' => '',
						'description'	=> esc_html__( 'Exclude posts that have this category. Using category-slug.', 'deeper' ),
			        ),       
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Load More Button?', 'deeper' ),
						'param_name' => 'loadmore',
						'value'      => array(
							'No' => '',
							'Enable' => 'true',
						),
						'std'		=> '',
					),
					array(
						'type'       => 'textfield',
						'heading'    => __( 'Button Text', 'deeper' ),
						'param_name' => 'loadmore_text',
						'value'      => __( 'Load More', 'deeper' ),
						'dependency' => array( 'element' => 'loadmore', 'value' => 'true' )
					),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Show Filter?', 'deeper' ),
						'param_name' => 'show_filter',
						'value'      => array(
							'No' => '',
							'Enable' => 'true',
						),
						'std'		=> '',
					),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Filter Button All?', 'deeper' ),
						'param_name' => 'filter_button_all',
						'value'      => array(
							'No' => '',
							'Enable' => __( 'All', 'deeper' ),
						),
						'std'		=> '',
						'dependency' => array( 'element' => 'show_filter', 'value' => 'true' ),
					),
					// CubePortfolio Controls
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Layout', 'deeper' ),
						'param_name' => 'layout',
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
						'value'      => array(
							'Responsive Grid' => 'grid',
							'Mosaic' => 'mosaic',
						),
						'std'		=> 'grid',
					),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Screen > 1024px', 'deeper' ),
						'param_name' => 'column',
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
						'value'      => array(
							'1 Column' => '1',
							'2 Columns' => '2',
							'3 Columns' => '3',
							'4 Columns' => '4',
						),
						'std'		=> '3',
					),
					array(
						'type' => 'textfield',
						'heading' => __( 'Vertical Spacing', 'deeper' ),
						'param_name' => 'gapv',
						'value' => '',
						'description'	=> __( 'Ex: 30.', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
			        array(
						'type' => 'textfield',
						'heading' => __( 'Horizontal Spacing', 'deeper' ),
						'param_name' => 'gaph',
						'value' => '',
						'description'	=> __( 'Ex: 30.', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Screen from 991px to 1024px', 'deeper' ),
						'param_name' => 'column2',
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
						'value'      => array(
							'1 Column' => '1',
							'2 Columns' => '2',
							'3 Columns' => '3',
						),
						'std'		=> '3',
					),
					array(
						'type' => 'textfield',
						'heading' => __( 'Vertical Spacing', 'deeper' ),
						'param_name' => 'gapv2',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
			        array(
						'type' => 'textfield',
						'heading' => __( 'Horizontal Spacing', 'deeper' ),
						'param_name' => 'gaph2',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Screen from 768px to 991px', 'deeper' ),
						'param_name' => 'column3',
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
						'value'      => array(
							'1 Column' => '1',
							'2 Columns' => '2',
							'3 Columns' => '3',
						),
						'std'		=> '2',
					),
					array(
						'type' => 'textfield',
						'heading' => __( 'Vertical Spacing', 'deeper' ),
						'param_name' => 'gapv3',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
			        array(
						'type' => 'textfield',
						'heading' => __( 'Horizontal Spacing', 'deeper' ),
						'param_name' => 'gaph3',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
					array(
						'type'       => 'dropdown',
						'heading'    => __( 'Screen < 768px', 'deeper' ),
						'param_name' => 'column4',
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
						'value'      => array(
							'1 Column' => '1',
							'2 Columns' => '2',
							'3 Columns' => '3',
						),
						'std'		=> '1',
					),
					array(
						'type' => 'textfield',
						'heading' => __( 'Vertical Spacing', 'deeper' ),
						'param_name' => 'gapv4',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
			        array(
						'type' => 'textfield',
						'heading' => __( 'Horizontal Spacing', 'deeper' ),
						'param_name' => 'gaph4',
						'value' => 'inherit',
						'description'	=> __( 'Ex: 30. Default: inherit from bigger', 'deeper' ),
						'group'      => __( 'CubePortfolio Controls', 'deeper' ),
			        ),
					// Animation 
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Enable Animation?', 'deeper' ),
						'param_name' => 'animation',
						'group' => esc_html__( 'Animation', 'deeper' ),
						'value'      => array( esc_html__( 'Yes, please.', 'deeper' ) => 'yes' ),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Animation', 'deeper' ),
						'param_name' => 'animation_effect',
						'value'      => array(
							'Fade In Up' => 'fadeInUp',
							'Fade In Down' => 'fadeInDown',
							'Fade In' => 'fadeIn',
							'Fade In Left' => 'fadeInLeft',
							'Fade In Right' => 'fadeInRight',
						),
						'std'		=> 'fadeInUp',
						'group' => esc_html__( 'Animation', 'deeper' ),
						'dependency' => array( 'element' => 'animation', 'value' => 'yes' ),
					),
		            array(
						'type' => 'textfield',
						'heading' => esc_html__('Animation Duration', 'deeper'),
						'param_name' => 'animation_duration',
						'value' => '0.75s',
						'description'	=> esc_html__('Ex: 0.1s, 0.15s', 'deeper'),
						'group' => esc_html__( 'Animation', 'deeper' ),
						'dependency' => array( 'element' => 'animation', 'value' => 'yes' ),
		            ),
		            array(
						'type' => 'textfield',
						'heading' => esc_html__('Animation Delay', 'deeper'),
						'param_name' => 'animation_delay',
						'value' => '0.3s',
						'description'	=> esc_html__('Ex: 0.1s, 0.15s', 'deeper'),
						'group' => esc_html__( 'Animation', 'deeper' ),
						'dependency' => array( 'element' => 'animation', 'value' => 'yes' ),
		            ),
		            array(
						'type' => 'textfield',
						'heading' => esc_html__('Extra Class', 'deeper'),
						'param_name' => 'class',
						'value' => '',
		            ),
        		)
			);
		}
	}
}

new Deeper_Portfolio_Ajax_Shortcode;
