<?php
class Deeper_Recent_Posts extends WP_Widget {
    // Holds widget settings defaults in constructor.
    protected $defaults;

    // Constructor
    function __construct() {
        $this->defaults = array(
            'title'             => 'Recent Posts', 
            'count'             => 3,
            'thumb_width'       => '90px'
        );

        parent::__construct(
            'deeper_latest_posts',
            esc_html__( 'Recent Posts', 'deeper' ),
            array(
                'classname'   => 'widget_latest_posts',
                'description' => esc_html__( 'Display latest blog posts.', 'deeper' )
            )
        );
    }

    // Display widget
    function widget( $args, $instance ) {
        $instance = wp_parse_args( $instance, $this->defaults );
        extract( $instance );

        echo $args['before_widget'];

        if ( ! empty( $title ) ) { echo $args['before_title'] . $title . $args['after_title']; }

        $thumb_css = '';

        if ( $thumb_width )
            $thumb_css .= 'width:'. intval( $thumb_width ) .'px;';

        $query_args = array(
            'post_type' => 'post',
            'posts_per_page' => intval( $count )
        );

        $query = new WP_Query( $query_args ); ?>

        <ul>
            <?php if ( $query->have_posts() ) : while ( $query->have_posts() ) : $query->the_post(); ?>
			<li class="clearfix">
                <div class="thumb" style="<?php echo esc_attr( $thumb_css ); ?>">
                    <?php
                    if ( has_post_thumbnail() ) {
                        the_post_thumbnail( 'octavian-post-widget' );
                    } ?>
                </div>

                <div class="texts">
                    <?php
                    printf( '
                        <h3 class="post-title"><a href="%s">%s</a></h3>',
                        esc_url( get_the_permalink() ),
                        get_the_title()
                    ); ?>

                    <span class="entry-date"><?php echo get_the_date('j M, Y'); ?></span>                            
                </div>
                     
            </li>
            <?php endwhile; wp_reset_postdata(); endif; ?>        
        </ul>
        
		<?php echo $args['after_widget'];
    }

    // Update widget
    function update( $new_instance, $old_instance ) {
        $instance                       = $old_instance;
        $instance['title']              = strip_tags( $new_instance['title'] );
        $instance['count']              = intval( $new_instance['count'] );
        $instance['thumb_width']        = strip_tags( $new_instance['thumb_width'] );

        return $instance;
    }

    // Widget setting
    function form( $instance ) {
        $instance = wp_parse_args( $instance, $this->defaults );       
        ?>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php echo esc_html( 'Title:', 'deeper' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>">
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'count' ) ); ?>"><?php echo esc_html( 'Count:', 'deeper' ); ?></label>
            <input class="widefat" type="number" id="<?php echo esc_attr( $this->get_field_id( 'count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'count' ) ); ?>" value="<?php echo esc_attr( $instance['count'] ); ?>">
        </p>

        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'thumb_width' ) ); ?>"><?php echo esc_html( 'Thumbnail Width:', 'deeper' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'thumb_width' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumb_width' ) ); ?>" type="text" size="2" value="<?php echo esc_attr( $instance['thumb_width'] ); ?>">
        </p>
    <?php
    }
}

// Register widget
function register_deeper_latest_posts() {
    register_widget( 'Deeper_Recent_Posts' );
}

add_action( 'widgets_init', 'register_deeper_latest_posts' );