<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Shortcode attributes
 * @var $atts
 * @var $el_class
 * @var $full_width
 * @var $full_height
 * @var $equal_height
 * @var $columns_placement
 * @var $content_placement
 * @var $parallax
 * @var $parallax_image
 * @var $css
 * @var $el_id
 * @var $video_bg
 * @var $video_bg_url
 * @var $video_bg_parallax
 * @var $parallax_speed_bg
 * @var $parallax_speed_video
 * @var $content - shortcode content
 * @var $css_animation
 * Shortcode class
 * @var WPBakeryShortCode_Vc_Row $this
 */
$el_class = $full_height = $parallax_speed_bg = $parallax_speed_video = $full_width = $equal_height = $flex_row = $columns_placement = $content_placement = $parallax = $parallax_image = $css = $el_id = $video_bg = $video_bg_url = $video_bg_parallax = $css_animation = '';
$disable_element = '';
$output = $after_output = '';
$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
extract( $atts );

wp_enqueue_script( 'wpb_composer_front_js' );


$el_class = $this->getExtraClass( $el_class ) . $this->getCSSAnimation( $css_animation );

$css_classes = array(
	'vc_row',
	'wpb_row',
	// deprecated
	'vc_row-fluid',
	$el_class,
	vc_shortcode_custom_css_class( $css ),
);

if ( 'yes' === $disable_element ) {
	if ( vc_is_page_editable() ) {
		$css_classes[] = 'vc_hidden-lg vc_hidden-xs vc_hidden-sm vc_hidden-md';
	} else {
		return '';
	}
}

if ( vc_shortcode_custom_css_has_property( $css, array(
	'border',
	'background',
) ) || $video_bg || $parallax
) {
	$css_classes[] = 'vc_row-has-fill';
}

if ( ! empty( $atts['gap'] ) ) {
	$css_classes[] = 'vc_column-gap-' . $atts['gap'];
}

if ( ! empty( $atts['rtl_reverse'] ) ) {
	$css_classes[] = 'vc_rtl-columns-reverse';
}

$wrapper_attributes = array();
// build attributes for wrapper
if ( ! empty( $el_id ) ) {
	$wrapper_attributes[] = 'id="' . esc_attr( $el_id ) . '"';
}
if ( ! empty( $full_width ) ) {
	$wrapper_attributes[] = 'data-vc-full-width="true"';
	$wrapper_attributes[] = 'data-vc-full-width-init="false"';
	if ( 'stretch_row_content' === $full_width ) {
		$wrapper_attributes[] = 'data-vc-stretch-content="true"';
	} elseif ( 'stretch_row_content_no_spaces' === $full_width ) {
		$wrapper_attributes[] = 'data-vc-stretch-content="true"';
		$css_classes[] = 'vc_row-no-padding';
	}
	$after_output .= '<div class="vc_row-full-width vc_clearfix"></div>';
}

if ( ! empty( $full_height ) ) {
	$css_classes[] = 'vc_row-o-full-height';
	if ( ! empty( $columns_placement ) ) {
		$flex_row = true;
		$css_classes[] = 'vc_row-o-columns-' . $columns_placement;
		if ( 'stretch' === $columns_placement ) {
			$css_classes[] = 'vc_row-o-equal-height';
		}
	}
}

if ( ! empty( $equal_height ) ) {
	$flex_row = true;
	$css_classes[] = 'vc_row-o-equal-height';
}

if ( ! empty( $content_placement ) ) {
	$flex_row = true;
	$css_classes[] = 'vc_row-o-content-' . $content_placement;
}

if ( ! empty( $flex_row ) ) {
	$css_classes[] = 'vc_row-flex';
}

if ( ! empty( $column_spacing ) ) {
	$css_classes[] = 'vc-custom-col-spacing-'. $column_spacing;
}

$has_video_bg = ( ! empty( $video_bg ) && ! empty( $video_bg_url ) && vc_extract_youtube_id( $video_bg_url ) );

$parallax_speed = $parallax_speed_bg;
if ( $has_video_bg ) {
	$parallax = $video_bg_parallax;
	$parallax_speed = $parallax_speed_video;
	$parallax_image = $video_bg_url;
	$css_classes[] = 'vc_video-bg-container';
	wp_enqueue_script( 'vc_youtube_iframe_api_js' );
}

if ( ! empty( $parallax ) ) {
	wp_enqueue_script( 'vc_jquery_skrollr_js' );
	$wrapper_attributes[] = 'data-vc-parallax="' . esc_attr( $parallax_speed ) . '"'; // parallax speed
	$css_classes[] = 'vc_general vc_parallax vc_parallax-' . $parallax;
	if ( false !== strpos( $parallax, 'fade' ) ) {
		$css_classes[] = 'js-vc_parallax-o-fade';
		$wrapper_attributes[] = 'data-vc-parallax-o-fade="on"';
	} elseif ( false !== strpos( $parallax, 'fixed' ) ) {
		$css_classes[] = 'js-vc_parallax-o-fixed';
	}
}

if ( ! empty( $parallax_image ) ) {
	if ( $has_video_bg ) {
		$parallax_image_src = $parallax_image;
	} else {
		$parallax_image_id = preg_replace( '/[^\d]/', '', $parallax_image );
		$parallax_image_src = wp_get_attachment_image_src( $parallax_image_id, 'full' );
		if ( ! empty( $parallax_image_src[0] ) ) {
			$parallax_image_src = $parallax_image_src[0];
		}
	}
	$wrapper_attributes[] = 'data-vc-parallax-image="' . esc_attr( $parallax_image_src ) . '"';
}
if ( ! $parallax && $has_video_bg ) {
	$wrapper_attributes[] = 'data-vc-video-bg="' . esc_attr( $video_bg_url ) . '"';
}

// Class for Canvas Background
$canvas = vc_param_group_parse_atts( $atts['canvas'] );
if ( $canvas ) $css_classes[] = 'position-relative';
if ( $canvas[0]['element'] ) $css_classes[] = 'has-canvas';

$css_class = preg_replace( '/\s+/', ' ', apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, implode( ' ', array_filter( array_unique( $css_classes ) ) ), $this->settings['base'], $atts ) );
$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';

$output .= '<div ' . implode( ' ', $wrapper_attributes ) . '>';
$output .= wpb_js_remove_wpautop( $content );

foreach ( $canvas as $key=>$item ) {
	if ( isset( $item['element'] ) ) {
		$cls = $css = '';
		if ( isset( $item['class'] ) ) $cls .= ' ' . $item['class'];

		switch ( $item['element'] ) {
			case 'image':
				if ( isset( $item['image'] ) ) {
					if ( isset($item['image_effect']) ) $cls .=  ' ' . $item['image_effect'];

					$canvas_css = 'position:absolute;';
					$parallax_atts = $top = $mobile_hide = $zoom_duration = $zoom_delay = $smoothness = '';

					// Position
					if ( isset( $item['image_post_top'] ) ) $canvas_css .= 'top:'. $item['image_post_top'] .';';
					if ( isset( $item['image_post_left'] ) ) $canvas_css .= 'left:'. $item['image_post_left'] .';';
					if ( isset( $item['image_post_bottom'] ) ) $canvas_css .= 'bottom:'. $item['image_post_bottom'] .';';
					if ( isset( $item['image_post_right'] ) ) $canvas_css .= 'text-align:right;right:'. $item['image_post_right'] .';';

					isset( $item['parallax_atts'] ) ? $parallax_atts = $item['parallax_atts'] : '';
					isset( $item['smoothness'] ) ? $smoothness = intval( $item['smoothness'] ) : $smoothness = 0;
					isset( $item['top'] ) ? $top = $item['top'] : $top = 0;
					if ( isset( $item['mobile_hide'] ) ) $mobile_hide = $item['mobile_hide'];

					$element = '';
					if ( $item['image'] ) {
						$image_css = '';
						if ( isset( $item['image_width'] ) ) $canvas_css .= 'width:' . $item['image_width'];
						$element = sprintf( '<div class="image-wrap" style="%2$s"><img src="%1$s" alt="Image"></div>', 
							esc_url( wp_get_attachment_image_src( $item['image'], 'full' )[0] ),
							$image_css
							);
					}

					if ( $item['image_effect'] == 'style-1' ) {
						$output .= sprintf( 
							'<div class="deeper-canvas %1$s %7$s" style="%2$s" data-inviewport="yes">
								<div class="parallax-wrap">
									<div class="canvas-item" data-parallax=\'{ %4$s, "smoothness" : %5$s}\' data-top="%6$s">
										%3$s
									</div>
								</div>
							</div>',
							esc_attr( $cls ),
							esc_attr( $canvas_css ),
							$element,
							esc_html( $parallax_atts ),
							esc_html( $smoothness ),
							esc_html( $top ),
							esc_html( $mobile_hide ) );

					} else {
						$zoom_config = '';
						if ( isset( $item['zoom_duration'] ) ) $zoom_config .= 'animation-duration:'. intval( $item['zoom_duration'] ) .'s;';
						if ( isset( $item['zoom_delay'] ) ) $zoom_config .= 'animation-delay:'. intval( $item['zoom_delay'] ) .'s;';
						$output .= sprintf( 
							'<div class="deeper-canvas %1$s %5$s" style="%2$s" data-inviewport="yes"><img src="%3$s" alt="canvas" style="%4$s"></div>',
							esc_attr( $cls ),
							esc_attr( $canvas_css ),
							esc_url( wp_get_attachment_image_src( $item['image'], 'full' )[0] ),
							esc_html( $zoom_config ),
							esc_html( $mobile_hide ) );
					}
				}
				
				break;
			
			case 'morphin':
				$inner_image = '';
				$svg_string = $shape_color = '';
				$cls .= ' ' . $item['shape'];
				$id = 'morph-' . rand();
				
				if ( isset( $item['inner_image'] ) ) 
					$inner_image = sprintf('<a xlink:href="#"><image %3$s clip-path="url(#%2$s)" xlink:href="%1$s"/></a>', 
						esc_url( wp_get_attachment_image_src( $item['inner_image'], 'full' )[0] ),
						$id,
						'width="100%" height="100%"' );

				isset( $item['shape_color'] ) ? $shape_color = $item['shape_color'] : $shape_color = '#f7f7f7'; 
				
				
				switch ( $item['shape'] ) {
					case 'shape-1':
						$svg_string = 
							'<svg viewBox="0 0 1920 775" preserveAspectRatio="none">
				                <path class="shape" fill="' .  $shape_color . '"
				                    d="M1160.9,762.9C895.1,778.9,564.4,512.2,361,527.2c-32.5,2.4-64.2,4.7-100.9,22.6
	c-92.3,45-100.1,131.7-165.1,135.4c-24,1.4-47.6-9.6-95-31.5c-25.9-12-46.4-24.4-60.6-33.7c7.5,57.2,15,114.4,22.5,171.6
	c686.3,0,1372.6,0,2058.9,0c-4.1-320.7-8.2-641.4-12.3-962C1988.7-128,1959.3-68.7,1920,0C1762.6,274.7,1494.4,742.7,1160.9,762.9z">
				                    
				                    <animate attributeName="d" begin="0s" dur="5s" repeatCount="indefinite" 

				                    values="M1160.9,762.9C895.1,778.9,564.4,512.2,361,527.2c-32.5,2.4-64.2,4.7-100.9,22.6
	c-92.3,45-100.1,131.7-165.1,135.4c-24,1.4-47.6-9.6-95-31.5c-25.9-12-46.4-24.4-60.6-33.7c7.5,57.2,15,114.4,22.5,171.6
	c686.3,0,1372.6,0,2058.9,0c-4.1-320.7-8.2-641.4-12.3-962C1988.7-128,1959.3-68.7,1920,0C1762.6,274.7,1494.4,742.7,1160.9,762.9z;

								    M1140.4,679.1c-236.5,8.7-529.3-138.3-731.2-122.6c-98.8,7.7-147.1,24.5-147.1,24.5
	c-91.1,31.6-115.2,74.6-167.5,63.3c-48.7-10.5-68.1-56.4-112.3-49c-19.9,3.3-34.4,15.7-42.9,24.5c7.5,57.2,15,114.4,22.5,171.6
	c686.3,0,1372.6,0,2058.9,0c-4.1-320.7-8.2-641.4-12.3-962C1992.8-117.7,1966-39.8,1920,48C1901.4,83.5,1589.2,662.7,1140.4,679.1z;

				                    M1160.9,762.9C895.1,778.9,564.4,512.2,361,527.2c-32.5,2.4-64.2,4.7-100.9,22.6
	c-92.3,45-100.1,131.7-165.1,135.4c-24,1.4-47.6-9.6-95-31.5c-25.9-12-46.4-24.4-60.6-33.7c7.5,57.2,15,114.4,22.5,171.6
	c686.3,0,1372.6,0,2058.9,0c-4.1-320.7-8.2-641.4-12.3-962C1988.7-128,1959.3-68.7,1920,0C1762.6,274.7,1494.4,742.7,1160.9,762.9z"/>
				                </path>
			            	</svg>';

						break;
					case 'shape-2':
						$svg_string = sprintf(
							'<svg viewBox="0 0 945 815">
								<g>
								<clipPath id="%1$s">
				                	<path class="shape1" fill="none" 
				                    d="M595.4,799.8c139.6-34.2,350.5-177.7,349-366c-1.3-163.2-64.7-297-344-386C96-113-111.6,172.9,58.3,300.3c176.2,132.2,239.3,150.1,179.1,306.4C161.2,805,389.1,850.4,595.4,799.8z">
				                    <animate attributeName="d" begin="0s" dur="7s" repeatCount="indefinite"

				                    values="M595.4,799.8c139.6-34.2,350.5-177.7,349-366c-1.3-163.2-64.7-297-344-386C96-113-111.6,172.9,58.3,300.3c176.2,132.2,239.3,150.1,179.1,306.4C161.2,805,389.1,850.4,595.4,799.8z;

				                    M649,793c139.6-34.2,266.5-195.3,265-383.6C912.7,246.2,899.3,158,620,69C115.6-91.8-77.9,159.6,92,287
	c176.2,132.2,196.1,160.7,136,317C151.8,802.2,442.7,843.6,649,793z;

									M702,766c139.6-34.2,140.5-69.7,139-258c-1.3-163.2,189.3-314-90-403C246.6-55.8-79.9,237.6,90,365
	c176.2,132.2,159.1,85.7,99,242C112.8,805.2,495.7,816.6,702,766z;

				                    M595.4,799.8c139.6-34.2,350.5-177.7,349-366c-1.3-163.2-64.7-297-344-386C96-113-111.6,172.9,58.3,300.3
	c176.2,132.2,239.3,150.1,179.1,306.4C161.2,805,389.1,850.4,595.4,799.8z"/>
				                	</path>

				                	<path class="shape2" fill="none" 
				                    d="M144.4,659.8c115-66.1,84.6-179.8,7.6-226.9c-93.7-57.3-129.2,32.7-75.6,72.9C135.5,550,60.9,707.8,144.4,659.8z">
				                    <animate attributeName="d" begin="0s" dur="5s" repeatCount="indefinite"

				                    values="M144.4,659.8c115-66.1,84.6-179.8,7.6-226.9c-93.7-57.3-129.2,32.7-75.6,72.9C135.5,550,60.9,707.8,144.4,659.8z;

				                    M210.8,595.8c115-66.1,42.3-130.5-34.8-177.7C82.3,360.8,22.4,551.8,76,592
	C135.1,636.3,127.2,643.8,210.8,595.8z;

				                    M173,623c115-66.1,80-157.7,3-204.9C82.3,360.8,15.4,501.3,69,541.5C128.1,585.8,89.5,671,173,623z;

				                    M144.4,659.8c115-66.1,84.6-179.8,7.6-226.9c-93.7-57.3-129.2,32.7-75.6,72.9C135.5,550,60.9,707.8,144.4,659.8z"/>
				                	</path>
				                </clipPath>
				                </g>	

				                <path class="shape1" fill="none" clip-path="url(#%1$s)"
				                    d="M595.4,799.8c139.6-34.2,350.5-177.7,349-366c-1.3-163.2-64.7-297-344-386C96-113-111.6,172.9,58.3,300.3c176.2,132.2,239.3,150.1,179.1,306.4C161.2,805,389.1,850.4,595.4,799.8z">			
				                </path>

				                <path class="shape2" fill="none" clip-path="url(#%1$s)"
				                    d="M144.4,659.8c115-66.1,84.6-179.8,7.6-226.9c-93.7-57.3-129.2,32.7-75.6,72.9C135.5,550,60.9,707.8,144.4,659.8z">			
				                </path>
				                %2$s
				                </svg>',
				            $id,
				            $inner_image
				        );

						break;
					case 'shape-3':
						$svg_string = sprintf(
							'<svg viewBox="0 0 1020 947">
								<g>
								<clipPath id="%1$s">
				                	<path class="shape1" fill="none" 
				                    d="M294.8,0.1C371-1.6,416.6,32.3,454.1,69.9c45.1,45.1,86.2,106.2,140.5,140.6
									c42.5,26.9,98.2,36.6,151.8,52.8c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,117.5,36.1,165.9,72.7c10.5,8,18.7,20.2,26.4,31.1
									c16.5,23.5,27.2,49.3,34.9,82.1c2.1,9,3.4,18.1,3.8,27.4c0,5.7,0.2,13.3,0.2,19c-0.5,15.9-2.7,29.5-4,41c-1.9,17.7-21.8,94.5-27,110
									c-17.5,52.4-81.7,180.9-192.2,248.2c-30.1,18.4-63.3,31.2-98.1,37.8c-44,8.1-109.4,7.7-153.7-1.9c-20.2-4.4-56.2-14.3-83.1-28.1
									c-69.1-35.2-123.3-84.1-154.1-154.2c-10.8-24.5-17.6-51.3-25.4-79.3c-4.9-17.7-5.2-37.2-9.4-54.7c-0.6-6.6-1.3-13.2-1.9-19.8
									c-6.4-26.7-7.6-56.4-20.7-76.4c-14.8-22.6-43.5-27.9-74.5-34.9c-19-4.3-39.3,0.6-57.5-3.8c-33.8-8.2-65.2-22.5-83-46.2
									C22.1,424.8,12.2,405,5.3,380.3c-10.9-39-3.2-100.8,7.5-134C45.6,145.6,100,84.5,182.6,34c21.6-13.2,47.6-21.7,74.5-29.3
									C264.3,2.8,290.3,2.9,294.8,0.1z">
				                    <animate attributeName="d" begin="0s" dur="7s" repeatCount="indefinite"

				                    values="M294.8,0.1C371-1.6,416.6,32.3,454.1,69.9c45.1,45.1,86.2,106.2,140.5,140.6
									c42.5,26.9,98.2,36.6,151.8,52.8c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,117.5,36.1,165.9,72.7c10.5,8,18.7,20.2,26.4,31.1
									c16.5,23.5,27.2,49.3,34.9,82.1c2.1,9,3.4,18.1,3.8,27.4c0,5.7,0.2,13.3,0.2,19c-0.5,15.9-2.7,29.5-4,41c-1.9,17.7-21.8,94.5-27,110
									c-17.5,52.4-81.7,180.9-192.2,248.2c-30.1,18.4-63.3,31.2-98.1,37.8c-44,8.1-109.4,7.7-153.7-1.9c-20.2-4.4-56.2-14.3-83.1-28.1
									c-69.1-35.2-123.3-84.1-154.1-154.2c-10.8-24.5-17.6-51.3-25.4-79.3c-4.9-17.7-5.2-37.2-9.4-54.7c-0.6-6.6-1.3-13.2-1.9-19.8
									c-6.4-26.7-7.6-56.4-20.7-76.4c-14.8-22.6-43.5-27.9-74.5-34.9c-19-4.3-39.3,0.6-57.5-3.8c-33.8-8.2-65.2-22.5-83-46.2
									C22.1,424.8,12.2,405,5.3,380.3c-10.9-39-3.2-100.8,7.5-134C45.6,145.6,100,84.5,182.6,34c21.6-13.2,47.6-21.7,74.5-29.3
									C264.3,2.8,290.3,2.9,294.8,0.1z;

				                    M298.7,11.5C375,9.9,416.6,32.3,454.1,69.9c45.1,45.1,105.1,85,159.5,119.3
									c42.5,26.9,79.2,57.9,132.8,74.1c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,117.5,36.1,165.9,72.7c10.5,8,18.7,20.2,26.4,31.1
									c16.5,23.5,27.2,49.3,34.9,82.1c2.1,9,3.4,18.1,3.8,27.4c0,5.7,0.2,13.3,0.2,19c-0.5,15.9-2.7,29.5-4,41
									c-1.9,17.7-40.4,90.4-45.5,105.9c-17.5,52.4-63.2,185-173.6,252.3c-30.1,18.4-67.4,18.4-102.1,24.9c-44,8.1-105.3,20.5-149.6,10.9
									c-20.2-4.4-56.2-14.3-83.1-28.1c-69.1-35.2-110.3-87.4-141-157.5c-10.8-24.5-30.6-48-38.5-75.9c-4.9-17.7-5.2-37.2-9.4-54.7
									c-0.6-6.6-1.3-13.2-1.9-19.8c-6.4-26.7-18.3-41.7-31.4-61.7c-14.8-22.6-32.9-42.7-63.8-49.7c-19-4.3-39.3,0.6-57.5-3.8
									c-33.8-8.2-65.2-22.5-83-46.2C22.1,424.8,12.2,405,5.3,380.3c-10.9-39,49.8-104.4,60.6-137.5c32.8-100.8,37.7-151,120.3-201.4
									c21.6-13.2,45.1-20.8,72-28.3C265.4,11,294.2,14.3,298.7,11.5z;

									M294.8,0.1C371-1.6,438.1,15.3,475.7,52.9c45.1,45.1,39.9,140.3,94.2,174.6
									c42.5,26.9,122.8,19.6,176.5,35.8c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,78.1,28.5,126.5,65c10.5,8,35.2,36.5,42.9,47.5
									c16.5,23.5,28.3,36.2,36,68.9c2.1,9,8.8,24.5,9.2,33.7c0,5.7-6.1,35.7-6.1,41.4c-0.5,15.9-13.3,32.1-14.6,43.7
									c-1.9,17.7-33.9,57.3-39.1,72.8c-17.5,52.4-35.1,118.8-145.5,186.1c-30.1,18.4-67.9,45.6-102.6,52.1c-44,8.1-88.2,17.3-132.5,7.7
									c-20.2-4.4-81.1-17.7-108-31.4c-69.1-35.2-116.3-32.3-147.1-102.4c-10.8-24.5-17.6-51.3-25.4-79.3c-4.9-17.7-5.2-37.2-9.4-54.7
									c-0.6-6.6-1.3-13.2-1.9-19.8c-6.4-26.7-22.1-37.1-35.2-57.1c-14.8-22.6-29-47.3-60-54.3c-19-4.3-42.1,7.4-60.3,3
									c-33.8-8.2-62.4-29.3-80.2-53C22.1,424.8,12.2,405,5.3,380.3c-10.9-39,28.4-239.2,39.1-272.3C77.2,7.3,100,84.5,182.6,34
									c21.6-13.2,47.6-21.7,74.5-29.3C264.3,2.8,290.3,2.9,294.8,0.1z;

				                    M294.8,0.1C371-1.6,416.6,32.3,454.1,69.9c45.1,45.1,86.2,106.2,140.5,140.6
									c42.5,26.9,98.2,36.6,151.8,52.8c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,117.5,36.1,165.9,72.7c10.5,8,18.7,20.2,26.4,31.1
									c16.5,23.5,27.2,49.3,34.9,82.1c2.1,9,3.4,18.1,3.8,27.4c0,5.7,0.2,13.3,0.2,19c-0.5,15.9-2.7,29.5-4,41c-1.9,17.7-21.8,94.5-27,110
									c-17.5,52.4-81.7,180.9-192.2,248.2c-30.1,18.4-63.3,31.2-98.1,37.8c-44,8.1-109.4,7.7-153.7-1.9c-20.2-4.4-56.2-14.3-83.1-28.1
									c-69.1-35.2-123.3-84.1-154.1-154.2c-10.8-24.5-17.6-51.3-25.4-79.3c-4.9-17.7-5.2-37.2-9.4-54.7c-0.6-6.6-1.3-13.2-1.9-19.8
									c-6.4-26.7-7.6-56.4-20.7-76.4c-14.8-22.6-43.5-27.9-74.5-34.9c-19-4.3-39.3,0.6-57.5-3.8c-33.8-8.2-65.2-22.5-83-46.2
									C22.1,424.8,12.2,405,5.3,380.3c-10.9-39-3.2-100.8,7.5-134C45.6,145.6,100,84.5,182.6,34c21.6-13.2,47.6-21.7,74.5-29.3
									C264.3,2.8,290.3,2.9,294.8,0.1z"/>
				                	</path>
				                </clipPath>
				                </g>	

				                <path class="shape1" fill="none" clip-path="url(#%1$s)"
				                    d="M294.8,0.1C371-1.6,416.6,32.3,454.1,69.9c45.1,45.1,86.2,106.2,140.5,140.6
									c42.5,26.9,98.2,36.6,151.8,52.8c14.6,4.4,28.2,4.8,42.4,9.4c64.4,21,117.5,36.1,165.9,72.7c10.5,8,18.7,20.2,26.4,31.1
									c16.5,23.5,27.2,49.3,34.9,82.1c2.1,9,3.4,18.1,3.8,27.4c0,5.7,0.2,13.3,0.2,19c-0.5,15.9-2.7,29.5-4,41c-1.9,17.7-21.8,94.5-27,110
									c-17.5,52.4-81.7,180.9-192.2,248.2c-30.1,18.4-63.3,31.2-98.1,37.8c-44,8.1-109.4,7.7-153.7-1.9c-20.2-4.4-56.2-14.3-83.1-28.1
									c-69.1-35.2-123.3-84.1-154.1-154.2c-10.8-24.5-17.6-51.3-25.4-79.3c-4.9-17.7-5.2-37.2-9.4-54.7c-0.6-6.6-1.3-13.2-1.9-19.8
									c-6.4-26.7-7.6-56.4-20.7-76.4c-14.8-22.6-43.5-27.9-74.5-34.9c-19-4.3-39.3,0.6-57.5-3.8c-33.8-8.2-65.2-22.5-83-46.2
									C22.1,424.8,12.2,405,5.3,380.3c-10.9-39-3.2-100.8,7.5-134C45.6,145.6,100,84.5,182.6,34c21.6-13.2,47.6-21.7,74.5-29.3
									C264.3,2.8,290.3,2.9,294.8,0.1z">			
				                </path>
				                %2$s
				                </svg>',
				            $id,
				            $inner_image
				        );

						break;

						case 'shape-4':
							if ( $shape_color == "#f7f7f7" ) $shape_color = 'url(#SVG_GID_1_)';

							$svg_string = 
								'<svg viewBox="0 0 1255 1304" preserveAspectRatio="none">
									<linearGradient id="SVG_GID_1_" gradientUnits="userSpaceOnUse" x1="-108.1274" y1="-143.6446" x2="1316.6895" y2="1281.1711">
										<stop  offset="0" style="stop-color:#F66767"/>
										<stop  offset="1" style="stop-color:#F68826"/>
									</linearGradient>
					                <path class="shape" fill="' .  $shape_color . '"
					                    d="M605.8,0C964.3,3.5,1255,290.6,1255,649s-295.1,705.1-649.2,649c-468.7-74.3-51.2-462.3-365.3-587.6C-227,523.8,36.6-5.5,605.8,0z">
					                    
					                    <animate attributeName="d" begin="0s" dur="15s" repeatCount="indefinite" 

					                    values="M605.8,0C964.3,3.5,1255,290.6,1255,649s-295.1,705.1-649.2,649c-468.7-74.3-51.2-462.3-365.3-587.6C-227,523.8,36.6-5.5,605.8,0z;

					                    M607.2-16.6c358.5,3.5,623,343.2,623,701.6s-120.8,655.6-474.9,599.5c-468.7-74.3-21.9-193.3-336-318.6C-48.3,779.3,38-22.1,607.2-16.6z;

					                    M669.5,4.8C1028,8.3,1246,276.6,1246,635s93.2,592.3-260.9,536.2c-468.7-74.3-246.6-28.9-560.7-154.2C-43.2,830.4,100.3-0.7,669.5,4.8z;

					                    M605.8,0C964.3,3.5,1255,290.6,1255,649s-295.1,705.1-649.2,649c-468.7-74.3-51.2-462.3-365.3-587.6C-227,523.8,36.6-5.5,605.8,0z"/>
					                </path>
				            	</svg>';

							break;
				}
				
				$output .= sprintf( '<div class="deeper-morph %2$s">%1$s</div>',
				 	$svg_string,
				 	$cls
				);
			
				break;
			
			case 'svg':
				$icon_string = dtp_get_svg( $item['svg'] );
				$css = '';
				if ( isset( $item['svg_color'] ) ) $css .= 'stroke:'. $item['svg_color'] .';';
				if ( isset( $item['svg_width'] ) ) $css .= 'width:'. $item['svg_width'] .';';
				if ( isset( $item['svg_rotate'] ) ) $css .= 'transform:rotate('. $item['svg_rotate'] .');';

				$output = sprintf( 
					'<div class="deeper-svg draw" data-inviewport="yes">
						<div class="svg-wrap" style="%2$s">%1$s</div>
					</div>',
					$icon_string,
					$css
				);
				
				break;
		}
	}
}

// Custom Background
if ( $bg_custom ) {
	$css_classes[] = 'position-relative';

	$bg_css = $bg_cls = '';
	$bg_cls .= $bg_custom;

	if ( $bg_color ) $bg_css .= 'background-color:' . $bg_color . ';';
	if ( $bg_rounded ) $bg_css .= 'border-radius:' . $bg_rounded . ';';
	if ( $bg_shadow ) $bg_css .= 'box-shadow:' . $bg_shadow . ';';
	if ( $bg_image) {
		$bg_css .= 'background-image:url('. esc_url( wp_get_attachment_image_src( $bg_image, 'full' )[0] ) .');';
		if ( $bg_position ) $bg_css .= 'background-position:'. $bg_position .';';
		if ( $bg_repeat ) $bg_css .= 'background-repeat:'. $bg_repeat .';';
		if ( $bg_size ) $bg_css .= 'background-size:'. $bg_size .';';
	}

	if ( $bg_color_one ) {
		if ( $bg_color_percent ) {
			$bg_css .= sprintf( 'background-image: linear-gradient(%6$s, %1$s %5$s , %1$s %3$s , %2$s %4$s );',
				$bg_color_one,
				$bg_color_two,
				intval( $bg_color_percent ) + 1 . '%',
				intval( $bg_color_percent ) . '%',
				'0%',
				$bg_direction
			);
		} else {
			$bg_css .= sprintf( 'background-image: linear-gradient(%3$s, %1$s, %2$s );',
				$bg_color_one,
				$bg_color_two,
				$bg_direction
			);
		}
	}
	
	$output .= sprintf( '<div class="deeper-background row %2$s" style="%1$s" data-inviewport="yes"></div>', $bg_css, $bg_cls );
}

$output .= '</div>';

$output .= $after_output;

return $output;
